==> Rintact_1.0.0.tar.gz: Rintact/man/intactXML2Graph.Rd <==
\name{intactXML2Graph}
\alias{intactXML2Graph}
\title{A function that takes a vector of IntAct XML file names
       and converts them to graph objects.}
\description{
The \code{intactXML2Graph} takes in a vector of related XML files
and generates a graph object based on the type of XML file.
}
\usage{
intactXML2Graph(intactFiles, type="interaction", directed=TRUE)
}
\arguments{
  \item{intactFiles}{A vector of IntAct XML file names. If the data 
  of a single experiment has been split into multiple XML files 
  (e.g. Ewing et al 2007), then each entry of the vector should contain
  one of these XML files. NB - different datasets should not be 
  put into the same vector.}
  \item{type}{A character string which is either "interaction" if the
  XML file contains experimental physical data or "complex" if the 
  XML file contains curated protein complex membership data.}
  \item{directed}{A logical. User defined parameter so that the return
  value with either be a directed or undirected graph object.}
}
\value{
 If type = "interaction," then a resulting intactGraph object is genertated on the
 aggregate of the XML files. If type = "complex," then a resulting intactHyperGraph
 object is generated on the aggregate of the XML files.
}
\references{The IntAct Database \url{http://www.ebi.ac.uk/intact/site/contents/downloads.jsf}.}
\author{T Chiang}

\seealso{\code{\link{interactionEntry-class}}, \code{\link{complexEntry-class}}}

\examples{
# parse complex data
}
\keyword{ models }

==> Rintact_1.6.0.tar.gz: Rintact/man/intactXML2Graph.Rd <==
\name{intactXML2Graph}
\alias{intactXML2Graph}
\title{A function that takes a vector of IntAct XML file names
       and converts them to graph objects.}
\description{
The \code{intactXML2Graph} takes in a vector of related XML files
and generates a graph object based on the type of XML file. In general,
the entry of this function should be that data from one experiment 
(this data might be divided into several XML files). If the XML file
contains data that should not be combined into one single graph, 
this function should not be called; the function 
\code{\link{separateXMLDataByExpt}} should be used instead.
}
\usage{
intactXML2Graph(intactFiles, type="interaction", directed=TRUE)
}
\arguments{
  \item{intactFiles}{A vector of IntAct XML file names. If the data 
  of a single experiment has been split into multiple XML files 
  (e.g. Ewing et al 2007), then each entry of the vector should contain
  one of these XML files. NB - different datasets should not be 
  put into the same vector.}
  \item{type}{A character string which is either "interaction" if the
  XML file contains experimental physical data or "complex" if the 
  XML file contains curated protein complex membership data.}
  \item{directed}{A logical. User defined parameter so that the return
  value with either be a directed or undirected graph object.}
}
\value{
 If type = "interaction," then a resulting intactGraph object is genertated on the
 aggregate of the XML files. If type = "complex," then a resulting intactHyperGraph
 object is generated on the aggregate of the XML files.
}
\references{Rintact: enabling computational analysis of molecular interaction data
from the IntAct repository - Tony Chiang; Nianhua Li; Sandra Orchard; Samuel 
Kerrien; Henning Hermjakob; Robert Gentleman; Wolfgang Huber
Bioinformatics 2007; doi: 10.1093/bioinformatics/btm518.}
\author{T Chiang}

\seealso{\code{\link{interactionEntry-class}}, \code{\link{complexEntry-class}},	
	\code{\link{separateXMLDataByExpt}}}

\examples{

}
\keyword{ models }
